@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
 # file convertDefault.py
 # This file is part of LyX, the document processor.
 # Licence details can be found in the file COPYING.
 
-# \author Herbert Vo
+# \author Herbert Voß
 # \author Bo Peng
 
 # Full author contact details are available in file CREDITS.
@@ -18,7 +18,18 @@
 
 # converts an image from $1 to $2 format
 import os, sys
-if os.system(r'convert -depth 8 "%s" "%s"' % (sys.argv[1], sys.argv[2])) != 0:
+
+opts = "-depth 8"
+# for pdf source formats, check whether convert supports the -define option
+if sys.argv[1][:4] == 'pdf:':
+    defopt = "-define pdf:use-cropbox=true"
+    fout = os.popen('convert ' + defopt + ' 2>&1')
+    output = fout.read()
+    fout.close()
+    if not 'unrecognized' in output.lower():
+        opts = defopt + ' ' + opts
+
+if os.system(r'convert %s "%s" "%s"' % (opts, sys.argv[1], sys.argv[2])) != 0:
     print >> sys.stderr, sys.argv[0], 'ERROR'
     print >> sys.stderr, 'Execution of "convert" failed.'
     sys.exit(1)
