@@ -13,20 +13,33 @@
 #define BUFFER_FUNCS_H
 
 #include "lyxlayout_ptr_fwd.h"
+#include "support/docstring.h"
 
 #include <string>
 
 
+namespace lyx {
+
+namespace support { class FileName; }
+
 class Buffer;
 class DocIterator;
 class ErrorList;
 class TeXErrors;
+class ParIterator;
 
 /**
  *  Loads a LyX file \c filename into \c Buffer
  *  and \return success status.
  */
-bool loadLyXFile(Buffer *, std::string const & filename);
+bool loadLyXFile(Buffer *, support::FileName const & filename);
+
+/**
+ *  Checks and loads a LyX file \param filename.
+ *  \retval the newly created \c Buffer pointer if successful or 0.
+ *  \retval 0 if the \c Buffer could not be created.
+ */
+Buffer * checkAndLoadLyXFile(support::FileName const & filename);
 
 /* Make a new file (buffer) with name \c filename based on a template
  * named \c templatename
@@ -35,21 +48,20 @@ Buffer * newFile(std::string const & filename, std::string const & templatename,
 		 bool isNamed = false);
 
 ///return the format of the buffer on a string
-std::string const BufferFormat(Buffer const & buffer);
-///
-void bufferErrors(Buffer const &, TeXErrors const &);
-///
-void bufferErrors(Buffer const &, ErrorList const &);
+std::string const bufferFormat(Buffer const & buffer);
+
+/// Fill in the ErrorList with the TeXErrors
+void bufferErrors(Buffer const &, TeXErrors const &, ErrorList &);
 
 /// Count the number of words in the text between these two iterators
 int countWords(DocIterator const & from, DocIterator const & to);
 
-/// Expand the counters for the labelstring of \c layout
-std::string expandLabel(Buffer const & buf, LyXLayout_ptr const & layout,
-			bool appendix);
-
 /// updates all counters
-void updateCounters(Buffer const &);
+void updateLabels(Buffer const &, bool childonly = false);
 
+///
+void checkBufferStructure(Buffer &, ParIterator const &);
+
+} // namespace lyx
 
 #endif // BUFFER_FUNCS_H
