@@ -12,8 +12,12 @@
 #ifndef OUTPUT_PLAINTEXT_H
 #define OUTPUT_PLAINTEXT_H
 
-#include <iosfwd>
-#include <string>
+#include "support/docstream.h"
+
+
+namespace lyx {
+
+namespace support { class FileName; }
 
 class Buffer;
 class OutputParams;
@@ -21,17 +25,19 @@ class Paragraph;
 
 
 ///
-void writeFileAscii(Buffer const & buf, std::string const &,
+void writePlaintextFile(Buffer const & buf, support::FileName const &,
 	OutputParams const &);
 
 ///
-void writeFileAscii(Buffer const & buf, std::ostream &, OutputParams const &);
+void writePlaintextFile(Buffer const & buf, odocstream &, OutputParams const &);
 
 ///
-void asciiParagraph(Buffer const & buf,
+void writePlaintextParagraph(Buffer const & buf,
 		    Paragraph const & paragraphs,
-		    std::ostream & ofs,
+		    odocstream & ofs,
 		    OutputParams const &,
 		    bool & ref_printed);
 
+} // namespace lyx
+
 #endif
