@@ -16,21 +16,23 @@
 #ifndef LSTRINGS_H
 #define LSTRINGS_H
 
+#include "support/docstring.h"
+
 #include <vector>
-#include <string>
 
 
 namespace lyx {
 namespace support {
 
-///
-int compare_no_case(std::string const & s, std::string const & s2);
+/// Compare \p s and \p s2, ignoring the case.
+/// Does not depend on the locale.
+int compare_no_case(docstring const & s, docstring const & s2);
 
-///
+/// Compare \p s and \p s2, ignoring the case of ASCII characters only.
 int compare_ascii_no_case(std::string const & s, std::string const & s2);
 
-///
-int compare_no_case(std::string const & s, std::string const & s2, unsigned int len);
+/// Compare \p s and \p s2, ignoring the case of ASCII characters only.
+int compare_ascii_no_case(docstring const & s, docstring const & s2);
 
 ///
 inline
@@ -63,37 +65,89 @@ bool isStrUnsignedInt(std::string const & str);
 ///
 bool isStrDbl(std::string const & str);
 
-///
+bool isHex(lyx::docstring const & str);
+
+int hexToInt(lyx::docstring const & str);
+
+/// is \p str pure ascii?
+bool isAscii(docstring const & str);
+
+/// is \p str pure ascii?
+bool isAscii(std::string const & str);
+
+/**
+ * Changes the case of \p c to lowercase.
+ * Don't use this for non-ASCII characters, since it depends on the locale.
+ * This overloaded function is only implemented because the char_type variant
+ * would be used otherwise, and we assert in this function that \p c is in
+ * the ASCII range.
+ */
 char lowercase(char c);
 
-///
+/**
+ * Changes the case of \p c to uppercase.
+ * Don't use this for non-ASCII characters, since it depends on the locale.
+ * This overloaded function is only implemented because the char_type variant
+ * would be used otherwise, and we assert in this function that \p c is in
+ * the ASCII range.
+ */
 char uppercase(char c);
 
+/// Changes the case of \p c to lowercase.
+/// Does not depend on the locale.
+char_type lowercase(char_type c);
+
+/// Changes the case of \p c to uppercase.
+/// Does not depend on the locale.
+char_type uppercase(char_type c);
+
 /// same as lowercase(), but ignores locale
 std::string const ascii_lowercase(std::string const &);
+docstring const ascii_lowercase(docstring const &);
 
-///
-std::string const lowercase(std::string const &);
+/// Changes the case of \p s to lowercase.
+/// Does not depend on the locale.
+docstring const lowercase(docstring const & s);
 
-///
-std::string const uppercase(std::string const &);
+/// Changes the case of \p s to uppercase.
+/// Does not depend on the locale.
+docstring const uppercase(docstring const & s);
+
+/// Does the string start with this prefix?
+bool prefixIs(docstring const &, char_type);
 
 /// Does the std::string start with this prefix?
 bool prefixIs(std::string const &, std::string const &);
+bool prefixIs(docstring const &, docstring const &);
 
 /// Does the string end with this char?
 bool suffixIs(std::string const &, char);
+bool suffixIs(docstring const &, char_type);
 
 /// Does the std::string end with this suffix?
 bool suffixIs(std::string const &, std::string const &);
 
 ///
-template <typename B>
-bool contains(std::string const & a, B b)
+inline bool contains(std::string const & a, std::string const & b)
 {
 	return a.find(b) != std::string::npos;
 }
 
+inline bool contains(docstring const & a, docstring const & b)
+{
+	return a.find(b) != docstring::npos;
+}
+
+inline bool contains(std::string const & a, char b)
+{
+	return a.find(b) != std::string::npos;
+}
+
+inline bool contains(docstring const & a, char_type b)
+{
+	return a.find(b) != docstring::npos;
+}
+
 ///
 bool containsOnly(std::string const &, std::string const &);
 
@@ -107,6 +161,7 @@ bool containsOnly(std::string const &, std::string const &);
 */
 std::string const token(std::string const & a, char delim, int n);
 
+docstring const token(docstring const & a, char_type delim, int n);
 
 /** Search a token in this string using the delim.
     Doesn't modify the original string. Returns -1 in case of
@@ -123,10 +178,24 @@ int tokenPos(std::string const & a, char delim, std::string const & tok);
 /// Substitute all \a oldchar with \a newchar
 std::string const subst(std::string const & a, char oldchar, char newchar);
 
+/// Substitute all \a oldchar with \a newchar
+docstring const subst(docstring const & a, char_type oldchar, char_type newchar);
+
 /// substitutes all instances of \a oldstr with \a newstr
 std::string const subst(std::string const & a,
 		   std::string const & oldstr, std::string const & newstr);
 
+/// substitutes all instances of \a oldstr with \a newstr
+docstring const subst(docstring const & a,
+		docstring const & oldstr, docstring const & newstr);
+
+/** Trims characters off the end and beginning of a string.
+    \code
+    trim("ccabccc", "c") == "ab".
+    \endcode
+*/
+docstring const trim(docstring const & a, char const * p = " ");
+
 /** Trims characters off the end and beginning of a string.
     \code
     trim("ccabccc", "c") == "ab".
@@ -140,13 +209,15 @@ std::string const trim(std::string const & a, char const * p = " ");
     \endcode
 */
 std::string const rtrim(std::string const & a, char const * p = " ");
+docstring const rtrim(docstring const & a, char const * p = " ");
 
 /** Trims characters off the beginning of a string.
     \code
-   ltrim("ababcdef", "ab") = "cdef"
+   ("ababcdef", "ab") = "cdef"
     \endcode
 */
 std::string const ltrim(std::string const & a, char const * p = " ");
+docstring const ltrim(docstring const & a, char const * p = " ");
 
 /** Splits the string by the first delim.
     Splits the string by the first appearance of delim.
@@ -158,6 +229,7 @@ std::string const ltrim(std::string const & a, char const * p = " ");
     \endcode
 */
 std::string const split(std::string const & a, std::string & piece, char delim);
+docstring const split(docstring const & a, docstring & piece, char_type delim);
 
 /// Same as split but does not return a piece
 std::string const split(std::string const & a, char delim);
@@ -165,62 +237,75 @@ std::string const split(std::string const & a, char delim);
 /// Same as split but uses the last delim.
 std::string const rsplit(std::string const & a, std::string & piece, char delim);
 
-/// Escapes non ASCII chars
-std::string const escape(std::string const & lab);
+/// Escapes non ASCII chars and other problematic characters that cause
+/// problems in latex labels.
+docstring const escape(docstring const & lab);
 
 /// gives a vector of stringparts which have the delimiter delim
 std::vector<std::string> const getVectorFromString(std::string const & str,
 					      std::string const & delim = std::string(","));
+std::vector<docstring> const getVectorFromString(docstring const & str,
+		docstring const & delim = from_ascii(","));
 
 // the same vice versa
 std::string const getStringFromVector(std::vector<std::string> const & vec,
 				 std::string const & delim = std::string(","));
 
+/// Search \p search_token in \p str and return the position if it is
+/// found, else -1. The last item in \p str must be "".
+int findToken(char const * const str[], std::string const & search_token);
+
+/// Convert internal line endings to line endings as expected by the OS
+docstring const externalLineEnding(docstring const & str);
+
+/// Convert line endings in any formnat to internal line endings
+docstring const internalLineEnding(docstring const & str);
+
 
 #ifdef I_AM_NOT_AFRAID_OF_HEADER_LIBRARIES
 
 #include <boost/format.hpp>
 
 template<class Arg1>
-string bformat(string const & fmt, Arg1 arg1)
+docstring bformat(docstring const & fmt, Arg1 arg1)
 {
-	return (boost::format(fmt) % arg1).str();
+	return (boost::basic_format<char_type>(fmt) % arg1).str();
 }
 
 
 template<class Arg1, class Arg2>
-string bformat(string const & fmt, Arg1 arg1, Arg2 arg2)
+docstring bformat(docstring const & fmt, Arg1 arg1, Arg2 arg2)
 {
-	return (boost::format(fmt) % arg1 % arg2).str();
+	return (boost::basic_format<char_type>(fmt) % arg1 % arg2).str();
 }
 
 
 template<class Arg1, class Arg2, class Arg3>
-string bformat(string const & fmt, Arg1 arg1, Arg2 arg2, Arg3 arg3)
+docstring bformat(docstring const & fmt, Arg1 arg1, Arg2 arg2, Arg3 arg3)
 {
-	return (boost::format(fmt) % arg1 % arg2 % arg3).str();
+	return (boost::basic_format<char_type>(fmt) % arg1 % arg2 % arg3).str();
 }
 
 
 template<class Arg1, class Arg2, class Arg3, class Arg4>
-string bformat(string const & fmt, Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4)
+docstring bformat(docstring const & fmt, Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4)
 {
-	return (boost::format(fmt) % arg1 % arg2 % arg3 % arg4).str();
+	return (boost::basic_format<char_type>(fmt) % arg1 % arg2 % arg3 % arg4).str();
 }
 
 #else
 
 template <class Arg1>
-std::string bformat(std::string const & fmt, Arg1);
+docstring bformat(docstring const & fmt, Arg1);
 
 template <class Arg1, class Arg2>
-std::string bformat(std::string const & fmt, Arg1, Arg2);
+docstring bformat(docstring const & fmt, Arg1, Arg2);
 
 template <class Arg1, class Arg2, class Arg3>
-std::string bformat(std::string const & fmt, Arg1, Arg2, Arg3);
+docstring bformat(docstring const & fmt, Arg1, Arg2, Arg3);
 
 template <class Arg1, class Arg2, class Arg3, class Arg4>
-std::string bformat(std::string const & fmt, Arg1, Arg2, Arg3, Arg4);
+docstring bformat(docstring const & fmt, Arg1, Arg2, Arg3, Arg4);
 
 #endif
 
