@@ -14,7 +14,7 @@
 #ifndef OS_H
 #define OS_H
 
-#include <string>
+#include "support/docstring.h"
 
 
 namespace lyx {
@@ -38,30 +38,40 @@ std::string current_root();
 ///
 shell_type shell();
 
+/// Name of the python interpreter
+std::string const python();
+
 /// Extract the path common to both @c p1 and @c p2. DBCS aware!
-std::string::size_type common_path(std::string const & p1, std::string const & p2);
+/// \p p1, \p p2 and the return value are encoded in utf8.
+docstring::size_type common_path(docstring const & p1, docstring const & p2);
 
 /// Converts a unix style path to host OS style.
+/// \p p and the return value are encoded in utf8.
 std::string external_path(std::string const & p);
 
 /// Converts a host OS style path to unix style.
+/// \p p and the return value are encoded in utf8.
 std::string internal_path(std::string const & p);
 
 /// Converts a unix style path list to host OS style.
+/// \p p and the return value are encoded in utf8.
 std::string external_path_list(std::string const & p);
 
 /// Converts a host OS style path list to unix style.
+/// \p p and the return value are encoded in utf8.
 std::string internal_path_list(std::string const & p);
 
 /**
  * Converts a unix style path into a form suitable for inclusion in a LaTeX
  * document.
+ * \p p is encoded in utf8.
  * Caution: This function handles only the OS specific part of that task.
  * Never use it directly, use lyx::support::latex_path instead.
  */
 std::string latex_path(std::string const & p);
 
 /// Is the path absolute?
+/// \p p is encoded in utf8.
 bool is_absolute_path(std::string const & p);
 
 /** Returns a string suitable to be passed to popen when
@@ -75,8 +85,8 @@ char const * popen_read_mode();
 char path_separator();
 
 /** If @c use_windows_paths is true, LyX will output Windows-style paths to
- *  latex files rather than posix ones. Currently, this option is used only
- *  under Cygwin.
+ *  latex files rather than posix ones. Obviously, this option is used only
+ *  under Windows.
  */
 void windows_style_tex_paths(bool use_windows_paths);
 
@@ -85,19 +95,32 @@ enum auto_open_mode {
 	EDIT
 };
 
-/** Check whether or not a file can be viewed by a default viewer 
+/** Check whether or not a file can be opened by a default viewer or editor.
  *  \param extension (without leading .)
- *  \mode can be opened in VIEW or EDIT mode
- *  \returns whether or not the format can be viewed
+ *  \param mode can be opened in VIEW or EDIT mode
+ *  \returns whether or not the format can be opened according to \p mode
  */
-bool canAutoOpenFile(std::string const & ext, auto_open_mode const mode=VIEW);
+bool canAutoOpenFile(std::string const & ext, auto_open_mode const mode = VIEW);
 
-/** view a file, with given command and parameter.
- *  \param filename
+/** View or edit a file with the default viewer or editor.
+ *  \param filename file to open (encoded in utf8)
  *  \param mode open in VIEW or EDIT mode
  *  \returns whether or not the file is viewed (or edited) successfully.
  */
-bool autoOpenFile(std::string const & filename, auto_open_mode const mode=VIEW);
+bool autoOpenFile(std::string const & filename, auto_open_mode const mode = VIEW);
+
+/** General font utilities.
+ *  FIXME: only MAC and WIN32 for now but it would be nice to convince
+ *  fontconfig to do the same for linux.
+ */
+
+/// Add fonts to the font subsystem, must be called before Application
+/// is initialized.
+void addFontResources();
+
+/// Restore original font resources, must be called after Application
+/// is destroyed.
+void restoreFontResources();
 
 } // namespace os
 } // namespace support
